API Documentation for repoze.evolution
======================================

.. _api_module:

:mod:`repoze.evolution`
-----------------------

.. automodule:: repoze.evolution

  .. autofunction:: evolve_to_latest


Interfaces
----------

.. autointerface:: repoze.evolution.interfaces.IEvolutionManager
   :members:
   :member-order: bysource

The ``repoze.evolution.ZODBEvolutionManager`` implements this interface.
